@@ -133,12 +133,12 @@ class DataStock1(DataStock0):
     # Adding ref / quantity one by one
     # ---------------------
 
-    def add_ref(self, size=None, key=None, data=None, harmonize=None, **kwds):
+    def add_ref(self, key=None, size=None, data=None, harmonize=None, **kwds):
         dref = {key: {'data': data, 'size': size, **kwds}}
         # Check consistency
         self.update(ddata=None, dref=dref, harmonize=harmonize)
 
-    def add_data(self, data=None, key=None, ref=None, harmonize=None, **kwds):
+    def add_data(self, key=None, data=None, ref=None, harmonize=None, **kwds):
         ddata = {key: {'data': data, 'ref': ref, **kwds}}
         # Check consistency
         self.update(ddata=ddata, dref=None, harmonize=harmonize)
@@ -207,6 +207,7 @@ class DataStock1(DataStock0):
         ) = _class1_check._remove_obj(
             key=key,
             which=which,
+            propagate=propagate,
             dobj0=self._dobj,
             ddata0=self._ddata,
             dref0=self._dref,
@@ -757,6 +758,7 @@ class DataStock1(DataStock0):
         deg=None,
         deriv=None,
         log_log=None,
+        nan0=None,
         # store vs return
         returnas=None,
         return_params=None,
@@ -783,6 +785,7 @@ class DataStock1(DataStock0):
             deg=deg,
             deriv=deriv,
             log_log=log_log,
+            nan0=nan0,
             # store vs return
             returnas=returnas,
             return_params=return_params,
